@@ -27,6 +27,11 @@ pls_spec <-
 # ------------------------------------------------------------------------------
 
 test_that('Multivariate model fitting', {
+  # Failures on r-devel are upstream in mixOmics. See
+  # https://github.com/mixOmicsTeam/mixOmics/issues/162
+  skip_on_cran()
+  skip_if(grepl("development", R.version$status))
+
   expect_error(
     parsnip_pls_multi <-
       plsmod::pls(num_comp = 3) %>%
@@ -77,6 +82,9 @@ test_that('Multivariate model fitting', {
 # ------------------------------------------------------------------------------
 
 test_that('Univariate model fitting', {
+  skip_on_cran()
+  skip_if(grepl("development", R.version$status))
+
   expect_error(
     parsnip_pls_uni <-
       plsmod::pls(num_comp = 3) %>%
@@ -126,6 +134,9 @@ test_that('Univariate model fitting', {
 # ------------------------------------------------------------------------------
 
 test_that('dummy variable encodings', {
+  skip_on_cran()
+  skip_if(grepl("development", R.version$status))
+
   data(penguins, package = "modeldata")
   penguins <- na.omit(penguins)
   expect_error(
